slabbe: Sébastien Labbé's Research code
=======================================

Description
-----------

This SageMath package contains various modules for experimentation with

- discrete dynamical systems
- combinatorics
- digital geometry
- visualization
- miscellaneous development tools

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/slabbe/

